/****************************/
// Data Preparation File
// This do file uses Stata 14 to assemble the mayor visits dataset (Table 2) for
// Foreign Aid and the Politics of Undeserved Credit Claiming
// Prepared by Cesi Cruz [cesi.cruz@ubc.ca]
//
// Uses two datasets available from the World Bank:
// panelhh_2006.dta    Household-level survey data from the KALAHI Impact Evaluation 2006
// panelbar_2006.dta   Village-level survey data from the KALAHI Impact Evaluation 2006 
/****************************/


/****************************/
// Step 1: Generating village level poverty measure
// Primary measure is POOR: based on self-reported poverty ("Place your family on this card: poor, on the line, not poor")
// Other measures used for robustness checks: construction materials used in the house
/****************************/

clear matrix
set more off

//Modify directory here
cd "/Users/cesicruz/Dropbox/Cesi & Christina/World Bank Paper/AJPS/Final Submission/replication materials"

//Load Kalahi Household Survey Data from Impact Evaluation (Available from the World Bank)
use panelhh_2006_stata13.dta, clear

//Clean poverty variable to use for village-level poverty measure 
gen poor = 0
replace poor = 1 if D132==3 //Place your family on this card: poor (vs. not poor or on the line)

//Other measures of poverty: house materials
//Roof made of strong materials (galvanized iron, aluminum, tile, concrete, brick, stone, asbestos)
gen roof_strong = 0
replace roof_strong = 1 if D95 == 1
replace roof_strong = . if D95==9

//Walls made of strong materials (galvanized iron, aluminum, tile, concrete, brick, stone, asbestos)
gen walls_strong = 0
replace walls_strong = 1 if D96 == 1
replace walls_strong = . if D96 ==9

//Generate village-level measures
collapse (mean) roof* walls* poor*, by(BARANGAY)
rename BARANGAY barangay
sort barangay
//save kc_visits_hh_avg, replace
//saveold kc_visits_hh_avg_stata12, replace version(12)
saveold kc_visits_hh_avg_stata13, replace
/****************************/


/****************************/
// Step 2: Cleaning the village-level variables used in the analysis
// Merging the poverty measure from step 1
/****************************/

use panelbar_full_2006_stata13.dta, clear


gen treat =  0
replace treat = 1 if TREAT==1

label variable F39A "Mayor Visits"
label variable F39B "Planning Officer Visits"
label variable F39C "Agrarian Reform Officer Visits"
label variable F39D "Social Worker Visits"
label variable F39E "Agriculture Officer Visits"
label variable F39F "Doctor/Health Worker Visits"
label variable F39G "Midwife Visits"

rename F39A visits_mayor
rename F39B visits_planning
rename F39C visits_agreform
rename F39D visits_soc
rename F39E visits_ag
rename F39F visits_dr
rename F39G visits_midwife

rename B3 population
rename B2 num_households
rename G40 ira
rename G54 bar_meetings
rename C16E has_market
rename C17E_1 min_market
rename C17E_2 dist_market
rename C13A road_dirt_pct

replace dist_market = .1 if has_market==1 & dist_market==888
replace dist_market = . if dist_market==888

foreach var of varlist population num_households ira{
	replace `var' = . if `var' == 9999 | `var' == 8888
}

foreach var of varlist population num_households ira dist_market{
	gen log_`var' = log(`var') if `var'!=.
}


gen muni_funds = 0
foreach var of varlist G41*{
	replace muni_funds = 1 if `var'==2
}

//Recoding no response
foreach var of varlist visits_*{
	replace `var' = . if `var' == 999
}

rename BARANGAY barangay
sort barangay

//Merging village level poverty survey data from step 1
merge barangay using kc_visits_hh_avg

//Optional: check merge for problems; _merge==3 for all observations
//tab _merge 

//Dropping merge variable
drop _merge

//Labeling other variables
label var road_dirt_pct "Percent Dirt Roads"
label var log_ira "Internal Revenue Allotment"
label var log_population "Population"
label var bar_meetings "Barangay Meetings"
label var muni_funds "Received Funding from Mayor"
label var treat "KALAHI"
label var poor "Poverty"
tabulate PROVINCE, gen(provis)
rename provis1 first_province_dummy //excluded

label variable log_num_households "Number of Households (log)"

//save ajps_visits_data, replace
//saveold ajps_visits_data_stata12, replace version(12)
saveold ajps_visits_data_stata13, replace
